@@ -1,5 +1,5 @@
 package AozoraBunko::Checkerkun;
-our $VERSION = "0.10";
+our $VERSION = "0.11";
 
 use 5.008001;
 use strict;
@@ -56,6 +56,7 @@ sub _default_options
         'hansp'            => 1, # 半角スペースをチェックする
         'hanpar'           => 1, # 半角カッコをチェックする
         'zensp'            => 0, # 全角スペースをチェックする
+        'zentilde'         => 1, # 全角チルダをチェックする
         '78hosetsu_tekiyo' => 1, # 78互換包摂の対象となる不要な外字注記をチェックする
         'hosetsu_tekiyo'   => 1, # 包摂の対象となる不要な外字注記をチェックする
         '78'               => 0, # 78互換包摂29字をチェックする
@@ -105,7 +106,7 @@ sub _tag_html
 #
 # ※［＃「口＋亞」、第3水準1-15-8、144-上-9］
 # が
-# ※［＃「口＋亞」、第3水準1-15-8、144-上-9］ → [78hosetsu_tekiyo]【唖】
+# ※［＃「口＋亞」、第3水準1-15-8、144-上-9］→[78hosetsu_tekiyo]【唖】
 # に変換され、
 #
 # ※［＃「にんべん＋曾」、第3水準1-14-41、144-上-9］
@@ -159,12 +160,10 @@ sub _check_all_hosetsu_tekiyo
 
 sub _is_gaiji
 {
-    my $char = shift; # コピーしないと、encode のタイミングで元の文字が消失してしまう。
+    my $char = shift; # コピーしないと元の文字が消失するので
 
-    # UTF-8からSJISに変換できなければ外字と判定
-    eval { $ENC->encode($char, Encode::FB_CROAK) };
-    return 1 if $@;
-    return 0;
+    # UTF-8からSJISに変換できなければ JIX X 0208:1997 外字と判定
+    return length $ENC->encode($char, Encode::FB_QUIET) ? 0 : 1;
 }
 
 sub check
@@ -245,6 +244,17 @@ sub check
                 $checked_text .= _tag_html($char, 'zensp', '全角スペース');
             }
         }
+        elsif ($self->{'zentilde'} && $char eq "\x{FF5E}")
+        {
+            if ($output_format eq 'plaintext')
+            {
+                $checked_text .= $char . '[zentilde]';
+            }
+            elsif ($output_format eq 'html')
+            {
+                $checked_text .= _tag_html($char, 'zentilde', '全角チルダ');
+            }
+        }
         elsif ( $self->{hanpar} && ($char eq '(' || $char eq ')') )
         {
             if ($output_format eq 'plaintext')
@@ -413,6 +423,7 @@ AozoraBunko::Checkerkun は、青空文庫工作員のための文字チェッ
       'hansp'            => 1, # 半角スペースをチェックする
       'hanpar'           => 1, # 半角カッコをチェックする
       'zensp'            => 0, # 全角スペースをチェックする
+      'zentilde'         => 1, # 全角チルダをチェックする
       '78hosetsu_tekiyo' => 1, # 78互換包摂の対象となる不要な外字注記をチェックする
       'hosetsu_tekiyo'   => 1, # 包摂の対象となる不要な外字注記をチェックする
       '78'               => 0, # 78互換包摂29字をチェックする
@@ -482,6 +493,8 @@ L<チェッカー君|http://www.aozora.jp/tools/checker.cgi>
 
 L<外字|http://www.aozora.gr.jp/annotation/external_character.html>
 
+L<波ダッシュ - Wikipedia|https://ja.wikipedia.org/wiki/%E6%B3%A2%E3%83%80%E3%83%83%E3%82%B7%E3%83%A5#Unicode.E3.81.AB.E9.96.A2.E9.80.A3.E3.81.99.E3.82.8B.E5.95.8F.E9.A1.8C>
+
 L<包摂 (文字コード) - Wikipedia|https://ja.wikipedia.org/wiki/%E5%8C%85%E6%91%82_(%E6%96%87%E5%AD%97%E3%82%B3%E3%83%BC%E3%83%89)>
 
 L<JIS漢字で包摂の扱いが変わる文字（[78] [jyogai] など）|http://www.aozora.gr.jp/newJIS-Kanji/gokan_henkou_list.html>
